@@ -51,7 +51,6 @@
 #define SCIM_PROP_LANGUAGE_ENGLISH    "/IMEngine/PRIME/Lang/English"
 
 PrimeConnection PrimeInstance::m_prime = PrimeConnection();
-int             PrimeInstance::m_prime_major_version = -2;
 
 PrimeInstance::PrimeInstance (PrimeFactory   *factory,
                               const String   &encoding,
@@ -66,6 +65,8 @@ PrimeInstance::PrimeInstance (PrimeFactory   *factory,
       m_modifying (false),
       m_registering (false),
       m_cancel_prediction (false),
+      m_preedition_visible (false),
+      m_lookup_table_visible (false),
       m_registering_cursor (0)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create PRIME Instance : ";
@@ -73,7 +74,6 @@ PrimeInstance::PrimeInstance (PrimeFactory   *factory,
     if (!m_prime.is_connected ()) {
         m_prime.open_connection (m_factory->m_command.c_str(),
                                  m_factory->m_typing_method.c_str());
-        m_prime_major_version = m_prime.major_version ();
     }
 }
 
@@ -212,6 +212,7 @@ PrimeInstance::select_candidate (unsigned int item)
         unsigned int pos = m_lookup_table.get_cursor_pos ();
         update_preedit_caret (m_candidates[pos].m_conversion.length ());
         hide_lookup_table ();
+        m_lookup_table_visible = false;
     }
 }
 
@@ -279,6 +280,9 @@ PrimeInstance::reset ()
     m_converting = false;
     m_modifying = false;
 
+    m_preedition_visible   = false;
+    m_lookup_table_visible = false;
+
     if (get_session())
         get_session()->edit_erase();
     m_lookup_table.clear ();
@@ -323,12 +327,26 @@ PrimeInstance::focus_in (void)
     SCIM_DEBUG_IMENGINE(2) << "focus_in.\n";
 
     install_properties ();
+
+    if (m_preedition_visible)
+        set_preedition ();
+    if (m_lookup_table_visible) {
+        update_lookup_table (m_lookup_table);
+        show_lookup_table ();
+    }
 }
 
 void
 PrimeInstance::focus_out (void)
 {
     SCIM_DEBUG_IMENGINE(2) << "focus_out.\n";
+
+#if 0
+    if (m_preedition_visible)
+        hide_preedit_string ();
+    if (m_lookup_table_visible)
+        hide_lookup_table ();
+#endif
 }
 
 void
@@ -410,6 +428,7 @@ PrimeInstance::set_preedition (void)
         attr_list.push_back (attr);
 
         show_preedit_string ();
+        m_preedition_visible = true;
         update_preedit_string (left + cursor + right, attr_list);
         update_preedit_caret (left.length ());
 
@@ -423,6 +442,7 @@ PrimeInstance::set_preedition (void)
         attr_list.push_back (attr);
 
         show_preedit_string ();
+        m_preedition_visible = true;
         update_preedit_string (cand.m_conversion, attr_list);
         update_preedit_caret (0);
 
@@ -434,10 +454,13 @@ PrimeInstance::set_preedition (void)
         if (m_factory->m_inline_prediction && !m_cancel_prediction)
             get_session()->conv_predict (m_candidates);
 
-        if (left.length () + cursor.length () + right.length () > 0)
+        if (left.length () + cursor.length () + right.length () > 0) {
             show_preedit_string ();
-        else
+            m_preedition_visible = true;
+        } else {
             hide_preedit_string ();
+            m_preedition_visible = false;
+        }
 
         if (!m_candidates.empty ()) {
             if (!left.empty () && cursor.empty () && right.empty ())
@@ -601,6 +624,7 @@ PrimeInstance::set_preedition_on_register (void)
     ADD_SEPARATOR_ATTR();
 
     show_preedit_string ();
+    m_preedition_visible = true;
     update_preedit_string (str, attr_list);
     update_preedit_caret (pos);
 }
@@ -639,12 +663,15 @@ PrimeInstance::set_prediction (void)
             m_candidates[0].m_conversion.length () > 0)
         {
             show_lookup_table ();
+            m_lookup_table_visible = true;
         } else {
             hide_lookup_table ();
+            m_lookup_table_visible = false;
         }
 
     } else {
         hide_lookup_table ();
+        m_lookup_table_visible = false;
     }
 
     update_lookup_table (m_lookup_table);
@@ -904,11 +931,13 @@ PrimeInstance::action_convert (void)
 
     if (m_candidates.size () > 0) {
         show_lookup_table ();
+        m_lookup_table_visible = true;
         update_lookup_table (m_lookup_table);
         select_candidate_no_direct (idx);
     } else {
         m_converting = false;
         hide_lookup_table ();
+        m_lookup_table_visible = false;
     }
 
     set_preedition ();
@@ -1004,6 +1033,7 @@ PrimeInstance::action_finish_selecting_candidates (void)
 
     set_preedition ();
     hide_lookup_table ();
+    m_lookup_table_visible = false;
 
     return true;
 }
@@ -1677,13 +1707,11 @@ PrimeInstance::action_set_language_japanese (void)
         m_language = SCIM_PRIME_LANGUAGE_JAPANESE;
         m_session->edit_insert (query.c_str ());
         set_preedition ();
-        set_prediction ();
     } else {
         m_language = SCIM_PRIME_LANGUAGE_UNKNOWN;
     }
 
-    if (m_properties.empty ())
-        install_properties ();
+    install_properties ();
     PropertyList::iterator it = std::find (m_properties.begin (),
                                            m_properties.end (),
                                            SCIM_PROP_LANGUAGE);
@@ -1731,13 +1759,11 @@ PrimeInstance::action_set_language_english (void)
         m_language = SCIM_PRIME_LANGUAGE_ENGLISH;
         m_session->edit_insert (query.c_str ());
         set_preedition ();
-        set_prediction ();
     } else {
         m_language = SCIM_PRIME_LANGUAGE_UNKNOWN;
     }
 
-    if (m_properties.empty ())
-        install_properties ();
+    install_properties ();
     PropertyList::iterator it = std::find (m_properties.begin (),
                                            m_properties.end (),
                                            SCIM_PROP_LANGUAGE);
