@@ -47,7 +47,6 @@ class PrimeInstance : public IMEngineInstanceBase
 
 private:
     static PrimeConnection  m_prime;
-    static int              m_prime_major_version;
 
     PrimeSession           *m_session;
 
@@ -71,6 +70,8 @@ private:
     bool                    m_modifying;
     bool                    m_registering;
     bool                    m_cancel_prediction;
+    bool                    m_preedition_visible;
+    bool                    m_lookup_table_visible;
 
     /* for register mode */
     String                  m_query_string;
