@@ -99,16 +99,18 @@ extern "C" {
 PrimeFactory::PrimeFactory (const String &lang,
                             const String &uuid,
                             const ConfigPointer &config)
-    : m_uuid (uuid),
-      m_config (config),
-      m_commit_on_upper (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT),
-      m_predict_on_preedition (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT),
-      m_inline_prediction (SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT),
-      m_auto_register (SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT),
+    : m_uuid                     (uuid),
+      m_config                   (config),
+      m_convert_on_period        (SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD_DEFAULT),
+      m_commit_period            (SCIM_PRIME_CONFIG_COMMIT_PERIOD_DEFAULT),
+      m_commit_on_upper          (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT),
+      m_predict_on_preedition    (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT),
+      m_inline_prediction        (SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT),
+      m_auto_register            (SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT),
       m_close_cand_win_on_select (SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT),
-      m_show_annotation (SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT),
-      m_show_usage (SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT),
-      m_show_comment (SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT)
+      m_show_annotation          (SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT),
+      m_show_usage               (SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT),
+      m_show_comment             (SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create PRIME Factory :\n";
     SCIM_DEBUG_IMENGINE(1) << "  Lang : " << lang << "\n";
@@ -190,6 +192,12 @@ PrimeFactory::reload_config (const ConfigPointer &config)
     m_typing_method
         = config->read (String (SCIM_PRIME_CONFIG_TYPING_METHOD),
                         String (SCIM_PRIME_CONFIG_TYPING_METHOD_DEFAULT));
+    m_convert_on_period
+        = config->read (String (SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD),
+                        SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD_DEFAULT);
+    m_commit_period
+        = config->read (String (SCIM_PRIME_CONFIG_COMMIT_PERIOD),
+                        SCIM_PRIME_CONFIG_COMMIT_PERIOD_DEFAULT);
     m_commit_on_upper
         = config->read (String (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER),
                         SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT);
